@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RT::Authen::OAuth2;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 use Net::OAuth2::Profile::WebServer;
 
@@ -11,6 +11,8 @@ use RT::Authen::OAuth2::Google;
 
 use URI::Escape;
 
+RT->AddStyleSheets('rt-authen-oauth2.css');
+
 =head1 NAME
 
 RT-Authen-OAuth2 - External authentication for OAuth 2 sources, like Google, Twitter, GitHub, etc.
@@ -21,7 +23,7 @@ External authentication for OAuth2 sources.
 
 =head1 RT VERSION
 
-Works with RT 4.4
+Works with RT 4.4 and 5
 
 =head1 DEPENDENCIES
 
@@ -71,7 +73,7 @@ or via the web at
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2016-2019 by Best Practical Solutions LLC
+This software is Copyright (c) 2016-2024 by Best Practical Solutions LLC
 
 This is free software, licensed under:
 
@@ -112,7 +114,7 @@ sub RequestAuthorization {
         redirect_uri => RT->Config->Get('OAuthRedirect'),
     );
 
-    my $ip = $ENV{REMOTE_ADDR};
+    my $ip = RT::Interface::Web::RequestENV('REMOTE_ADDR') || 'UNKNOWN';
     RT::Logger->info("OAuth 2 redirect from RequestAuthorization() from $ip");
     RT::Interface::Web::Redirect($auth->authorize);
 }
@@ -137,7 +139,7 @@ sub LogUserIn {
     # generic_error is displayed to the user to avoid leaking information
     # about the existance and status of user accounts in RT
     my $generic_error = RT->SystemUser->loc("Cannot login. Please contact your administrator.");
-    my $ip = $ENV{REMOTE_ADDR};
+    my $ip = RT::Interface::Web::RequestENV('REMOTE_ADDR') || 'UNKNOWN';
 
     RT::Logger->info("OAuth2 user already logged in, aborting; new request from $ip") if $session->{CurrentUser} and $session->{CurrentUser}->Id;
     return (0, $generic_error) if $session->{CurrentUser} and $session->{CurrentUser}->Id;
